@@ -19,6 +19,8 @@ import gzip
 import math
 import datetime
 import time
+import pickle
+import base64
 from collections import Counter
 
 
@@ -1085,3 +1087,32 @@ def load_yaml(path, encoding='UTF-8'):
         with open(path, 'r') as f:
             config = yaml.load(f.read())
     return config
+
+
+def to_byte(data):
+    """to_byte方法用于将对象转换为字节
+
+    Parameters
+    ----------
+    data : object
+        任意对象
+    Returns
+    ----------
+    """
+    data = base64.b64encode(pickle.dumps(data)).decode("ascii")
+    return data
+
+
+def from_byte(data):
+    """from_byte方法用于将字节对象还原
+
+    Parameters
+    ----------
+    param : str
+
+    Returns
+    ----------
+    """
+    data = base64.b64decode(data)
+    data = pickle.loads(data)
+    return data
\ No newline at end of file
